@@ -19,6 +19,8 @@ async def exec_access(inc: InputContext,
                       model: Type[AbstractDbModel],
                       container: GenericDependencyContainer = None,
                       fetch_fields: List[str] = None,
+                      drop_cols: List[str] = None,
+                      full_info: bool = False,
                       middleware: Type[ModelLoader] = ModelLoader,
                       external_callback: AccessCallback = None,
                       retrieved_callback: AccessCallback = None
@@ -61,7 +63,7 @@ async def exec_access(inc: InputContext,
                     asyncio.create_task(external_callback(retrieved_all, inc, middleware))
                 if retrieved_callback:
                     return await retrieved_callback(retrieved_all, inc, middleware)
-                res = [await model.values_dict() for model in retrieved_all]
+                res = [await model.values_dict(drop_cols=drop_cols, full_info=full_info) for model in retrieved_all]
                 return res, total
             retrieved = await middleware.read(model, entity_id, inc.identity,
                                               container=container, fetch_fields=fetch_fields, **kwargs)
@@ -87,8 +89,8 @@ async def exec_access(inc: InputContext,
     if retrieved_callback:
         return await retrieved_callback(retrieved, inc, middleware)
     if isinstance(retrieved, list):
-        return [await i.values_dict() for i in retrieved]
-    return await retrieved.values_dict()
+        return [await i.values_dict(drop_cols=drop_cols, full_info=full_info) for i in retrieved]
+    return await retrieved.values_dict(drop_cols=drop_cols, full_info=full_info)
 
 
 async def exec_access_with_total(inc: InputContext,
