@@ -168,6 +168,15 @@ class AddonsLoader:
                     cell_plugins.append(pl)
             return cell_plugins
 
+    async def find_addon_by_name(self, name: str) -> List[ApiAddon]:
+        middlewares = await self.store.get_item("addon")
+        if not middlewares:
+            return []
+        else:
+            for pl in middlewares:
+                if pl.name == name and pl.enabled:
+                    return pl
+
     async def on_store_update(self, event: StoreUpdateEvent):
         if event.key == "addon":
             await self.store.set_item("addon", event.value, send_event=False)
